simsopt.\_core package
======================

Submodules
----------

simsopt.\_core.derivative module
--------------------------------

.. automodule:: simsopt._core.derivative
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

simsopt.\_core.descriptor module
--------------------------------

.. automodule:: simsopt._core.descriptor
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

simsopt.\_core.finite_difference module
---------------------------------------

.. automodule:: simsopt._core.finite_difference
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

simsopt.\_core.optimizable module
---------------------------------

.. automodule:: simsopt._core.optimizable
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

simsopt.\_core.util module
--------------------------

.. automodule:: simsopt._core.util
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

